@@ -57,6 +57,8 @@ extern int gle_debug;
 #include "run.h"
 #include "fn.h"
 
+using namespace std;
+
 /*---------------------------------------------------------------------------*/
 /* bin = 10..29  (now 31), binstr = 30..49, fn= 60...139, userfn=LOCAL_START_INDEX..nnn */
 #define stack_bin(i,p) stack_op(pcode, stk, stkp, &nstk, i + BINARY_OPERATOR_OFFSET, p + curpri)
@@ -205,7 +207,7 @@ void GLEPolish::internalPolish(GLEPcode& pcode, int *rtype) {
 			unary = 2;
 			pcode.erase(pcode.end() - 1);
 			pcode.erase(pcode.end() - 1);
-			savelen = -1; // lenght set from calling code
+			savelen = -1; // length set from calling code
 			//cout <<token<<endl;
 		}
 		dbg gprint("First word token via (1=unary %d) cts {%s}\n ", unary, token.c_str());
